#!/usr/bin/env python
# CESYS Software License - Version 1.0 - January 1st, 2016
#
# Permission is hereby granted, free of charge, to any person or organization
# obtaining a copy of the software and accompanying documentation covered by
# this license (the "Software") to use, reproduce, display, distribute,
# execute, and transmit the Software, and to prepare derivative works of the
# Software, and to permit third-parties to whom the Software is furnished to
# do so, all subject to the following:
#
# The software must only be used to operate hardware manufactured by 
# CESYS GmbH, Herzogenaurach.
#
# The copyright notices in the Software and this entire statement, including
# the above license grant, this restriction and the following disclaimer,
# must be included in all copies of the Software, in whole or in part, and
# all derivative works of the Software, unless such copies or derivative
# works are solely in the form of machine-executable object code generated by
# a source language processor.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
# SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
# FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
# 
# Written by Thomas Hoppe <thomas.hoppe@cesys.com>, 2016
from CeboMsrApiPython import LibraryInterface, DeviceType

# CeboMsr - Python example - Counter.
#
# This example shows how to use a counter. Digital I/O #1 is wired
# to the counter, so every time this I/O is pulsed, the counter will
# react on this event.
#
# Requirements: IO-1 must be connected to CNT (IO-0 on Cebo Stick).

def counterTest(device):
    """
    Configuration and running.
    device: Device to use for test.
    """
    # Create local copies, this shortens the source.
    dp0 = device.getDigitalPorts()[0]
    cnt = device.getCounters()[0]

    # Set IO-1 as output.
    dp0.setOutputEnableMask(0x02)

    # Enable the counter.
    cnt.setEnabled(True)

    # Check the counters current value.
    print("Counter before starting: %d" % cnt.read())

    # Pulse IO-1 3 times.
    for _ in range(3):
        dp0.write(0x02)
        dp0.write(0x00)

    # Check the counters current value.
    print("Counter should be 3: %d" % cnt.read())

    # Reset and ...
    cnt.reset()

    # ... disable the counter.
    cnt.setEnabled(False)

    # Check the counters current value.
    print("Counter should be 0: %d" % cnt.read())

    # Pulse IO-1 3 times, the counter should ignore these pulses.
    for _ in range(3):
        dp0.write(0x02)
        dp0.write(0x00)

    # Check the counters current value.
    print("Counter should still be 0: %d" % cnt.read())

def main():
    """
    The examples main method.
    """
    try:
        # Search for devices ...
        devices = LibraryInterface.enumerate(DeviceType.All)

        # If at least one has been found, use the first one ...
        if (len(devices) > 0):
            device = devices[0]

            # Open device, nothing can be done without doing this.
            device.open()

            # *** DIGITAL PORTS AND ANALOG OUTPUTS ARE MODIFIED DURING THIS ***
            # *** SECTION, SO DO NOT CONNECT ANY PERIPHERALS WITHOUT STUDYING ***
            # *** THE ACTIONS DONE HERE, OTHERWISE YOUR PERIPHERALS MAY BE DAMAGED !!! ***
            counterTest(device)

            # Finalize device usage, this free's up the device, so it can be used
            # again, including other applications.
            device.close()
    except Exception as e:
        print(e)

if (__name__ == "__main__"):
    main()
